top_n_plots: Outputs a bar graph giving the top n in frequency in specified column of
dataframe
Description
top_n_plots returns a bar graph that shows the top n (n is given as a
parameter) labels in a given column in the dataframe with the highest
frequency
Usage
top_n_plots(df, n, colName, color = "default colors")
Arguments
df
A dataframe in FishNet2 standard format (by using read.csv())
n
The number of the labels with the highest frequencies to be included
in the graph
colName
The column name that the graph outputs
color
Color of the bars, by default is a different color for each bar
Value
A bar graph
Details
This is a function to create and output a bar graph giving the top n in
frequency in specified column of dataframe (columns include 'ScientificName',
'Family', 'Country','State/Province','County').